# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test
# FileName:      __init__.py
# Author:       zhang
# Datetime:     2024/11/5 下午6:41
# Description:
# 
# ---------------------------------------------------------------------------
import functools
import logging
import os
import time


def log():
    logger = logging.getLogger()
    logger.setLevel(logging.INFO)
    report_path = os.path.join(os.path.dirname(__file__), "report")
    log_path = os.path.join(report_path, "log")
    log_name = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime()) + ".log"
    log_file_path = os.path.join(log_path, log_name)
    handle = logging.FileHandler(filename=log_file_path, mode="a", encoding="utf-8")
    formatter = logging.Formatter(
        fmt="'%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s"
    )
    handle.setFormatter(formatter)
    logger.addHandler(handle)
    return logger


log = log()


def loger(func_name):
    @functools.wraps(func_name)  # 装饰器返回内部函数时，沿用被装饰者的名称
    def inner(*args, **kwargs):
        # __code__: 返回函数或方法的对象，可以获取函数或者方法的属性。
        # __code__.co_filename：获取函数或方法所在的py文件
        # __code__.co_firstlineno：获取函数或方法所在的py文件开始行号
        log.info(
            f"执行的功能为：{func_name.__name__}, 功能描述为：{func_name.__doc__}, 所在的py文件为：{func_name.__code__.co_filename}， 所在的行为：{func_name.__code__.co_firstlineno}行，形参的值为：{args}或{kwargs}")
        try:
            result = func_name(*args, **kwargs)
        except Exception as e:
            log.error(
                f"执行的功能为：{func_name.__name__}, 功能描述为：{func_name.__doc__}, 所在的py文件为：{func_name.__code__.co_filename}， 所在的行为：{func_name.__code__.co_firstlineno}行，形参的值为：{args}或{kwargs}"
                f"错误的类型为：{type(e)}, 错误的描述为：{e}")
            raise e
        else:
            return result

    return inner
